@@ -3,20 +3,21 @@
 
     Copyright (c) 2001 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License version 2 or at your option version 3 as published by
-    the Free Software Foundation.
+ This program is free software; you can redistribute it and/or
+ modify it under the terms of the GNU General Public License as
+ published by the Free Software Foundation; either version 2 of
+ the License or (at your option) version 3 or any later version
+ accepted by the membership of KDE e.V. (or its successor approved
+ by the membership of KDE e.V.), which shall act as a proxy 
+ defined in Section 14 of version 3 of the license.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
 
+ You should have received a copy of the GNU General Public License
+ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #include <QDomElement>
@@ -37,7 +38,7 @@
 #include <QTreeView>
 #include <QHeaderView>
 #include "ListView.h"
-#include "ListView.moc"
+
 #include "ListViewSettings.h"
 
 static QString formatByteSize(qlonglong amountInKB, int units) {
@@ -64,22 +65,22 @@ static QString formatByteSize(qlonglong amountInKB, int units) {
 
     switch(units) {
       case UnitsKB:
-        return kString.arg(KGlobal::locale()->formatNumber(amountInKB, 0));
+        return kString.arg(KLocale::global()->formatNumber(amountInKB, 0));
       case UnitsMB:
         amount = amountInKB/1024.0;
-        return mString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return mString.arg(KLocale::global()->formatNumber(amount, 1));
       case UnitsGB:
         amount = amountInKB/(1024.0*1024.0);
         if(amount < 0.1 && amount > 0.05) amount = 0.1;
-        return gString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return gString.arg(KLocale::global()->formatNumber(amount, 1));
       case UnitsTB:
         amount = amountInKB/(1024.0*1024.0*1024.0);
         if(amount < 0.1 && amount > 0.05) amount = 0.1;
-        return tString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return tString.arg(KLocale::global()->formatNumber(amount, 1));
       case UnitsPB:
         amount = amountInKB/(1024.0*1024.0*1024.0*1024.0);
         if(amount < 0.1 && amount > 0.05) amount = 0.1;
-        return pString.arg(KGlobal::locale()->formatNumber(amount, 1));
+        return pString.arg(KLocale::global()->formatNumber(amount, 1));
       default:
           return "";  // error
     }
@@ -100,7 +101,7 @@ ListView::ListView(QWidget* parent, const QString& title, SharedSettings *workSh
 
     mView->setContextMenuPolicy( Qt::CustomContextMenu );
     mView->header()->setContextMenuPolicy( Qt::CustomContextMenu );
-    connect(mView, SIGNAL(customContextMenuRequested(QPoint)), SLOT(showContextMenu(QPoint)));
+    connect(mView, &QTreeView::customContextMenuRequested, this, &ListView::showContextMenu);
     connect(mView->header(), SIGNAL(customContextMenuRequested(QPoint)), SLOT(showColumnContextMenu(QPoint)));
 
     mView->setAlternatingRowColors(true);
@@ -400,7 +401,7 @@ ListView::configureSettings()
 {
     lvs = new ListViewSettings(this, "ListViewSettings");
     Q_CHECK_PTR(lvs);
-    connect(lvs, SIGNAL(applyClicked()), SLOT(applySettings()));
+    connect(lvs, &ListViewSettings::applyClicked, this, &ListView::applySettings);
 
 /*    QPalette pal = monitor->palette();
     lvs->setGridColor(pal.color(QPalette::Link));
